class Birds:
    def __init__(self):
        ''' Constructor for this class. '''
        # Create some member animals
        self.members = ['Sparrow', 'Robin', 'Duck']
 
 
    def printMembers(self):
        print('Printing members of the Birds class')
        for member in self.members:
           print('\t%s ' % member)



class Mammals:
    def __init__(self):
        ''' Constructor for this class. '''
        # Create some member animals
        self.members = ['Tiger', 'Elephant', 'Wild Cat']
 
 
    def printMembers(self):
        print('Printing members of the Mammals class')
        for member in self.members:
            print('\t%s ' % member)





class Mammals:
    def __init__(self):
        self.members = ['Eagle', 'Sparrow', 'Mina']
    def printMembers(self):
        print('Printing ...')
        for member in self.members:
            print('\t member = %s' % member)




from setuptools import setup

setup(name = 'myAnimals',
        description = 'Distinguish mammals and birds',
        url = '',
        author = 'Saeed Mirshekari',
        author_email = 'saeed.mirshekari@gmail.com',
        license = 'MIT',
        packages = ['myAnimals'],
        zip_self = False)
